summaryrefslogtreecommitdiffstats
path: root/kooka/kocrocrad.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kooka/kocrocrad.cpp')
-rw-r--r--kooka/kocrocrad.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kooka/kocrocrad.cpp b/kooka/kocrocrad.cpp
index 384dbe69..b9365767 100644
--- a/kooka/kocrocrad.cpp
+++ b/kooka/kocrocrad.cpp
@@ -26,7 +26,7 @@
/* $Id$ */
-#include <layout.h>
+#include <tqlayout.h>
#include <tqlabel.h>
#include <tqfileinfo.h>
#include <tqtooltip.h>
@@ -129,7 +129,7 @@ EngineError ocradDialog::setupGui()
else
m_ocrCmd = res;
/** layout detection button **/
conf->setGroup( CFG_GROUP_OCRAD );
int layoutDetect = conf->readNumEntry( CFG_OCRAD_LAYOUT_DETECTION, 0 );
kdDebug(28000) << "Layout detection from config: " << layoutDetect << endl;
@@ -137,7 +137,7 @@ EngineError ocradDialog::setupGui()
(void) new KSeparator( KSeparator::HLine, page);
TQHBox *hb1 = new TQHBox(page);
hb1->setSpacing( KDialog::spacingHint() );
- (void) new TQLabel( i18n("OCRAD layout analysis mode: "), hb1);
+ (void) new TQLabel( i18n("OCRAD tqlayout analysis mode: "), hb1);
m_layoutMode = new TQComboBox(hb1);
m_layoutMode->insertItem(i18n("No Layout Detection"), 0 );
m_layoutMode->insertItem(i18n("Column Detection"), 1 );
@@ -129,7 +129,7 @@ EngineError ocradDialog::setupGui()
else
m_ocrCmd = res;
- /** layout detection button **/
+ /** tqlayout detection button **/
conf->setGroup( CFG_GROUP_OCRAD );
int layoutDetect = conf->readNumEntry( CFG_OCRAD_LAYOUT_DETECTION, 0 );